@@ -9,6 +9,7 @@ def register_commands(cli: click.Group) -> None:
     from .download import download
     from .login import login
     from .logout import logout
+    from .plugin import plugin
     from .update import update
     from .whoami import whoami
     # placeholder for more commands
@@ -19,11 +20,13 @@ def register_commands(cli: click.Group) -> None:
     cli.add_command(update)
     cli.add_command(download)
     cli.add_command(commands)
+    cli.add_command(plugin)
 
     # groups
     from .auth import auth
     from .extension import extension
     from .ida import ida
+    from .ke import ke
     from .license import license
     from .share import share
 
@@ -32,3 +35,4 @@ def register_commands(cli: click.Group) -> None:
     cli.add_command(share)
     cli.add_command(license)
     cli.add_command(extension)
+    cli.add_command(ke)
