@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-import sys
-
 import questionary
 import rich_click as click
 
@@ -13,7 +11,7 @@ from hcli.lib.console import console
 
 
 @click.command()
-@click.argument("name", required=False)
+@click.option("-n", "--name", help="Name for the new key")
 @require_auth
 @async_command
 async def create(name: str | None) -> None:
@@ -31,7 +29,7 @@ async def create(name: str | None) -> None:
         existing_keys = await keys.get_keys()
         if any(k.name == key_name for k in existing_keys):
             console.print(f"[red]An API key with name [underline]{key_name}[/underline] already exists.[/red]")
-            sys.exit(1)
+            raise click.Abort()
 
         # Confirm key creation
         if not await safe_ask_async(questionary.confirm(f"Do you want to create a new API key {key_name}?")):
@@ -74,4 +72,4 @@ async def create(name: str | None) -> None:
 
     except Exception as e:
         console.print(f"[red]Failed to create API key: {e}[/red]")
-        sys.exit(1)
+        raise click.Abort()
