@@ -5,7 +5,7 @@ import rich_click as click
 
 @click.group()
 def share() -> None:
-    """Share commands."""
+    """Share files with Hex-Rays."""
     pass
 
 
