@@ -1,23 +1,18 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import Optional
 
 import questionary
 import rich_click as click
 from questionary import Choice
 
 from hcli.commands.common import safe_ask_async
-from hcli.lib.api.asset import SHARED, asset
+from hcli.lib.api.asset import SHARED, asset, get_permissions_from_acl_type
 from hcli.lib.auth import get_auth_service
 from hcli.lib.commands import async_command, auth_command
 from hcli.lib.console import console
 from hcli.lib.constants import cli
-
-
-def get_email_domain(email: str) -> str:
-    """Extract domain from email address."""
-    return email.split("@")[-1] if "@" in email else ""
+from hcli.lib.util.string import get_email_domain
 
 
 @auth_command()
@@ -25,13 +20,13 @@ def get_email_domain(email: str) -> str:
 @click.option(
     "-a",
     "--acl",
-    type=click.Choice(["public", "private", "authenticated", "domain"]),
-    help="Access control level (public, private, authenticated, domain)",
+    type=click.Choice(["private", "authenticated", "domain"]),
+    help="Access control level (private, authenticated, domain)",
 )
 @click.option("-c", "--code", help="Upload a new version for an existing code")
 @click.option("-f", "--force", is_flag=True, help="Upload a new version for an existing code")
 @async_command
-async def put(path: Path, acl: Optional[str], code: Optional[str], force: bool) -> None:
+async def put(path: Path, acl: str | None, code: str | None, force: bool) -> None:
     """Upload a shared file."""
 
     # Validate file exists
@@ -46,6 +41,7 @@ async def put(path: Path, acl: Optional[str], code: Optional[str], force: bool)
     # Get user info for domain ACL
     auth_service = get_auth_service()
     user = auth_service.get_user()
+    assert user is not None, "User not found"
     domain = get_email_domain(user["email"]) if user else ""
 
     # Determine ACL if not provided
@@ -54,20 +50,30 @@ async def put(path: Path, acl: Optional[str], code: Optional[str], force: bool)
             Choice("[private] Just for me", value="private"),
             Choice(f"[domain] Anyone from my domain (@{domain})", value="domain"),
             Choice("[authenticated] Anyone authenticated with the link", value="authenticated"),
-            Choice("[public] Anyone with the link", value="public"),
         ]
 
         acl = await safe_ask_async(
             questionary.select("Pick a visibility 🔎", choices=choices, default="authenticated", style=cli.SELECT_STYLE)
         )
 
+    assert acl is not None, "ACL not selected"
+
     # Conflicts check
     if force and code:
         console.print("[red]Error: --force and --code cannot be used together[/red]")
         raise click.Abort()
 
     # Upload the file
-    result = await asset.upload_file(SHARED, str(path), user["email"], acl, force, code)
+    acl_fields = get_permissions_from_acl_type(acl, user["email"])
+    result = await asset.upload_asset(
+        SHARED,
+        str(path),
+        allowed_segments=acl_fields["allowed_segments"],
+        allowed_emails=acl_fields["allowed_emails"],
+        metadata={"acl_type": acl},
+        force=force,
+        code=code,
+    )
 
     console.print("[green]✓ File uploaded successfully![/green]")
     console.print(f"[bold]Share Code:[/bold] {result.code}")
