@@ -4,17 +4,19 @@ from __future__ import annotations  # only needed for Python <3.10
 
 import hashlib
 from pathlib import Path
-from typing import Dict, ForwardRef, List, Optional
+from typing import ForwardRef
 
 import httpx
 from pydantic import BaseModel
 
+from hcli.env import ENV
+from hcli.lib.util.string import get_email_domain
+
 from .common import get_api_client
 
 SHARED = "shared"
 INSTALLERS = "installers"
 
-
 # Forward reference for TreeNode
 TreeNodeType = ForwardRef("TreeNode")
 
@@ -22,21 +24,21 @@ TreeNodeType = ForwardRef("TreeNode")
 class TreeNode(BaseModel):
     name: str
     type: str = "file"
-    children: List["TreeNode"] | None = None
+    children: "list[TreeNode] | None" = None
     asset: Asset
 
 
 class Asset(BaseModel):
-    email: Optional[str] = None
+    email: str | None = None
     filename: str
     size: int = 0
     key: str
-    code: Optional[str] = None
-    created_at: Optional[str] = None
-    expires_at: Optional[str] = None
-    url: Optional[str] = None
+    code: str | None = None
+    created_at: str | None = None
+    expires_at: str | None = None
+    url: str | None = None
     version: int = 0
-    metadata: Optional[dict] = None
+    metadata: dict | None = None
 
 
 class PagedAsset(BaseModel):
@@ -45,19 +47,37 @@ class PagedAsset(BaseModel):
     offset: int
     limit: int
     total: int
-    items: List[Asset]
+    items: list[Asset]
+
+
+class Metadata(BaseModel):
+    name: str
+
+
+class RequiredField(BaseModel):
+    description: str
+    example: str
+
+
+class Bucket(BaseModel):
+    filename: str
+    metadata: Metadata
+    requiredMetadata: dict[str, RequiredField]
 
 
 class PagingFilter(BaseModel):
     """Paging filter parameters."""
 
-    limit: Optional[int] = 1000
-    offset: Optional[int] = 0
+    limit: int | None = 1000
+    offset: int | None = 0
 
 
 class UploadResponse(BaseModel):
     """Upload response."""
 
+    bucket: str
+    key: str
+    version: int
     code: str
     url: str
     download_url: str
@@ -66,14 +86,20 @@ class UploadResponse(BaseModel):
 class AssetAPI:
     """File sharing API client."""
 
-    async def upload_file(
+    async def get_bucket(self, bucket: str):
+        client = await get_api_client()
+        data = await client.get_json(f"/api/assets/buckets/{bucket}")
+        return Bucket(**data)
+
+    async def upload_asset(
         self,
         bucket: str,
         file_path: str,
-        user_email: str,
-        acl_type: str = "authenticated",
+        allowed_segments: list[str] | None = None,
+        allowed_emails: list[str] | None = None,
+        metadata: dict | None = None,
         force: bool = False,
-        code: Optional[str] = None,
+        code: str | None = None,
     ) -> UploadResponse:
         """Upload a file for sharing."""
         file_path_obj = Path(file_path)
@@ -89,21 +115,22 @@ class AssetAPI:
 
         client = await get_api_client()
 
-        # Request upload URL
-        # convert acl_type to allowed_segments & allowed_users
-        acl_fields = get_permissions_from_acl_type(acl_type, user_email)
         upload_data = {
             "filename": filename,
             "size": size,
             "force": force,
             "status": "active",
             "checksum": checksum,
-            **acl_fields,
-            "metadata": {
-                "acl_type": acl_type,
-            },
         }
 
+        # Add optional fields if provided
+        if allowed_segments is not None:
+            upload_data["allowed_segments"] = allowed_segments
+        if allowed_emails is not None:
+            upload_data["allowed_emails"] = allowed_emails
+        if metadata is not None:
+            upload_data["metadata"] = metadata
+
         if code:
             upload_data["code"] = code
 
@@ -112,6 +139,7 @@ class AssetAPI:
         upload_url = response.get("url")
         file_code = response.get("code")
         key = response.get("key")
+        version = response.get("version")
 
         if upload_url:
             # Upload the file (without content parameter to use streaming)
@@ -119,9 +147,10 @@ class AssetAPI:
             # Confirm upload
             response = await client.post_json(f"/api/assets/{bucket}/{key}", {})
 
-        from hcli.env import ENV
-
         return UploadResponse(
+            bucket=bucket,
+            key=key,
+            version=version,
             code=file_code,
             url=f"{ENV.HCLI_PORTAL_URL}/share/{file_code}",
             download_url=f"{ENV.HCLI_API_URL}/api/assets/s/{file_code}",
@@ -147,7 +176,7 @@ class AssetAPI:
         data = await client.get_json(f"/api/assets/{bucket}/{code}/versions")
         return Asset(**data)
 
-    async def get_files(self, bucket: str, filter_params: Optional[PagingFilter] = None) -> PagedAsset:
+    async def get_files(self, bucket: str, filter_params: PagingFilter | None = None) -> PagedAsset:
         """Get all shared files for the current user."""
         if filter_params is None:
             filter_params = PagingFilter()
@@ -158,12 +187,12 @@ class AssetAPI:
         )
         return PagedAsset(**data)
 
-    async def get_file(self, bucket: str, key: str) -> Optional[Asset]:
+    async def get_file(self, bucket: str, key: str) -> Asset | None:
         client = await get_api_client()
         data = await client.get_json(f"/api/assets/{bucket}/{key}")
         return Asset(**data)
 
-    async def get_files_tree(self, bucket: str, filter_params: Optional[PagingFilter] = None) -> List[TreeNode]:
+    async def get_files_tree(self, bucket: str, filter_params: PagingFilter | None = None) -> list[TreeNode]:
         """Get all shared files for the current user."""
         if filter_params is None:
             filter_params = PagingFilter()
@@ -175,17 +204,8 @@ class AssetAPI:
         return [TreeNode(**item) for item in data]
 
 
-def get_email_domain(email: str) -> str:
-    return email.lower().split("@")[-1]
-
-
-def get_permissions_from_acl_type(acl_type: str, user_email: str) -> Dict[str, Optional[List[str]]]:
-    if acl_type == "public":
-        return {
-            "allowed_segments": None,
-            "allowed_emails": None,
-        }
-    elif acl_type == "authenticated":
+def get_permissions_from_acl_type(acl_type: str, user_email: str) -> dict[str, list[str] | None]:
+    if acl_type == "authenticated":
         return {
             "allowed_segments": ["authenticated"],
             "allowed_emails": None,
