@@ -1,7 +1,5 @@
 """API Keys management client."""
 
-from typing import List, Optional
-
 from pydantic import BaseModel
 
 from .common import get_api_client
@@ -12,7 +10,7 @@ class ApiKey(BaseModel):
 
     name: str
     created_at: str
-    last_used_at: Optional[str]
+    last_used_at: str | None
     request_count: int
 
 
@@ -25,7 +23,7 @@ class ApiKeyToken(BaseModel):
 class KeysAPI:
     """API Keys management client."""
 
-    async def get_keys(self) -> List[ApiKey]:
+    async def get_keys(self) -> list[ApiKey]:
         """Get all API keys for the current user."""
         client = await get_api_client()
         data = await client.get_json("/api/keys")
