@@ -3,8 +3,9 @@ import json
 import webbrowser
 from http.server import BaseHTTPRequestHandler, HTTPServer
 from threading import Thread
-from typing import Any, Dict, List, Optional
+from typing import Any
 
+from gotrue import SyncSupportedStorage
 from supabase import Client, create_client
 from supabase.lib.client_options import SyncClientOptions
 
@@ -21,15 +22,15 @@ from hcli.lib.constants.auth import (
 class AuthService:
     """Singleton authentication service handling multiple credentials."""
 
-    _instance: Optional["AuthService"] = None
+    _instance: "AuthService | None" = None
 
     def __init__(self):
         if AuthService._instance is not None:
             raise Exception("AuthService is a singleton. Use AuthService.instance")
 
         # Create custom storage class for Supabase
-        class SyncSupportedStorage:
-            def get_item(self, key: str) -> Optional[str]:
+        class ConfigSyncSupportedStorage(SyncSupportedStorage):
+            def get_item(self, key: str) -> str | None:
                 return config_store.get_string(key) or None
 
             def set_item(self, key: str, value: str) -> None:
@@ -40,21 +41,21 @@ class AuthService:
 
         # Create Supabase client with custom storage
         options = SyncClientOptions(
-            auto_refresh_token=False, persist_session=True, storage=SyncSupportedStorage(), flow_type="implicit"
+            auto_refresh_token=False, persist_session=True, storage=ConfigSyncSupportedStorage(), flow_type="implicit"
         )
 
         self.supabase: Client = create_client(ENV.HCLI_SUPABASE_URL, ENV.HCLI_SUPABASE_ANON_KEY, options)
 
         # Current session state (for active interactive auth)
-        self.session: Optional[Any] = None
-        self.user: Optional[Any] = None
-        self._server_thread: Optional[Thread] = None
-        self._oauth_result: Optional[Dict[str, str]] = None
+        self.session: Any | None = None
+        self.user: Any | None = None
+        self._server_thread: Thread | None = None
+        self._oauth_result: dict[str, str] | None = None
 
         # Multi-source auth state
-        self._auth_config: Optional[CredentialsConfig] = None
-        self._current_source: Optional[Credentials] = None
-        self._forced_credentials: Optional[str] = None  # For --auth-source override
+        self._auth_config: CredentialsConfig | None = None
+        self._current_source: Credentials | None = None
+        self._forced_credentials: str | None = None  # For --auth-source override
 
     @classmethod
     def instance(cls) -> "AuthService":
@@ -63,7 +64,7 @@ class AuthService:
             cls._instance = cls()
         return cls._instance
 
-    def init(self, forced_credentials: Optional[str] = None) -> None:
+    def init(self, forced_credentials: str | None = None) -> None:
         """Initialize the auth service and load credentials."""
         self._forced_credentials = forced_credentials
         self._load_auth_config()
@@ -108,7 +109,7 @@ class AuthService:
                 if self._current_source.token:
                     # Set the token in Supabase client
                     user_response = self.supabase.auth.get_user()
-                    if user_response.user:
+                    if user_response and user_response.user:
                         self.user = user_response.user
                         self.session = self.supabase.auth.get_session()
             except Exception:
@@ -122,17 +123,17 @@ class AuthService:
             return True
         return False
 
-    def list_credentials(self) -> List[Credentials]:
+    def list_credentials(self) -> list[Credentials]:
         """Get all available credentials."""
         if not self._auth_config:
             return []
         return list(self._auth_config.credentials.values())
 
-    def get_current_credentials(self) -> Optional[Credentials]:
+    def get_current_credentials(self) -> Credentials | None:
         """Get the currently active credentials."""
         return self._current_source
 
-    def get_default_credentials_name(self) -> Optional[str]:
+    def get_default_credentials_name(self) -> str | None:
         """Get the name of the default credentials."""
         return self._auth_config.default if self._auth_config else None
 
@@ -193,11 +194,50 @@ class AuthService:
         if self._current_source.type == CredentialType.KEY:
             return bool(self._current_source.token)
         elif self._current_source.type == CredentialType.INTERACTIVE:
-            return self.session is not None and self.session.user is not None
+            # For interactive auth, check if session is valid by attempting to get user
+            if self.session is not None and self.session.user is not None:
+                return True
+            # If we have credentials but no valid session, try to refresh
+            if self._current_source.token:
+                try:
+                    user_response = self.supabase.auth.get_user()
+                    if user_response and user_response.user:
+                        self.user = user_response.user
+                        self.session = self.supabase.auth.get_session()
+                        return True
+                except Exception:
+                    # Token exists but is expired/invalid
+                    return False
+            return False
 
         return False
 
-    def get_auth_type(self) -> Dict[str, str]:
+    def has_expired_session(self) -> bool:
+        """Check if user has credentials but session is expired."""
+        # No expired session for environment API key
+        if ENV.HCLI_API_KEY:
+            return False
+
+        # No expired session if no credentials exist
+        if not self._current_source:
+            return False
+
+        # Only interactive auth can have expired sessions
+        if self._current_source.type != CredentialType.INTERACTIVE:
+            return False
+
+        # Has credentials but session is invalid/expired
+        if self._current_source.token and (self.session is None or self.session.user is None):
+            try:
+                # Try to verify if token is actually expired
+                user_response = self.supabase.auth.get_user()
+                return user_response is None or user_response.user is None
+            except Exception:
+                return True
+
+        return False
+
+    def get_auth_type(self) -> dict[str, str]:
         """Get the type of authentication being used."""
         # Environment variable takes precedence
         if ENV.HCLI_API_KEY:
@@ -209,7 +249,7 @@ class AuthService:
         source_origin = "forced" if self._forced_credentials else "default"
         return {"type": self._current_source.type, "source": source_origin}
 
-    def get_api_key(self) -> Optional[str]:
+    def get_api_key(self) -> str | None:
         """Get API key from current source."""
         # Check environment variable first (legacy behavior)
         if ENV.HCLI_API_KEY:
@@ -219,7 +259,7 @@ class AuthService:
             return self._current_source.token
         return None
 
-    def get_user(self) -> Optional[Dict[str, str]]:
+    def get_user(self) -> dict[str, str] | None:
         """Get current user information."""
         # Handle environment variable case
         if ENV.HCLI_API_KEY and not self._current_source:
@@ -246,14 +286,14 @@ class AuthService:
 
         return {"email": self._current_source.email}
 
-    def get_access_token(self) -> Optional[str]:
+    def get_access_token(self) -> str | None:
         """Get access token from current session."""
         return self.session.access_token if self.session else None
 
     # Auth flow methods (updated for multi-source)
     def _create_or_update_interactive_credentials(
-        self, email: str, token: str, name: Optional[str] = None
-    ) -> Optional[Credentials]:
+        self, email: str, token: str, name: str | None = None
+    ) -> Credentials | None:
         """Create new or update existing interactive credentials for the given email."""
         # Check if interactive credentials already exist for this email
         existing_source = None
@@ -286,7 +326,7 @@ class AuthService:
 
             return source
 
-    async def login_interactive(self, name: Optional[str] = None, force: bool = False) -> Optional[Credentials]:
+    async def login_interactive(self, name: str | None = None, force: bool = False) -> Credentials | None:
         """Login using OAuth flow and create new credentials."""
         await self._login_flow(prompt=force)
         if self.is_logged_in() and self.session and self.session.user:
@@ -295,7 +335,7 @@ class AuthService:
             return self._create_or_update_interactive_credentials(email, token, name)
         return None
 
-    async def login_otp(self, email: str, name: Optional[str] = None, force: bool = False) -> bool:
+    async def login_otp(self, email: str, name: str | None = None, force: bool = False) -> bool:
         """Login using OTP and create credentials."""
         if force:
             self.logout_current()
@@ -303,14 +343,14 @@ class AuthService:
         self.supabase.auth.sign_in_with_otp({"email": email})
         return True
 
-    def verify_otp(self, email: str, otp: str, name: Optional[str] = None) -> Optional[Credentials]:
+    def verify_otp(self, email: str, otp: str, name: str | None = None) -> Credentials | None:
         """Verify OTP and create credentials."""
         try:
             self.supabase.auth.verify_otp({"email": email, "token": otp, "type": "email"})
 
             # Refresh session after OTP verification
             user_response = self.supabase.auth.get_user()
-            if user_response.user:
+            if user_response and user_response.user:
                 self.user = user_response.user
                 self.session = self.supabase.auth.get_session()
 
@@ -320,7 +360,7 @@ class AuthService:
             pass
         return None
 
-    async def add_api_key_credentials(self, name: str, token: str) -> Optional[Credentials]:
+    async def add_api_key_credentials(self, name: str, token: str) -> Credentials | None:
         """Add a new API key credentials."""
         # Get user email from API
         try:
@@ -508,7 +548,7 @@ class AuthService:
 
             # Refresh user and session info
             user_response = self.supabase.auth.get_user()
-            if user_response.user:
+            if user_response and user_response.user:
                 self.user = user_response.user
                 self.session = self.supabase.auth.get_session()
                 print(f"{self.user.email} logged in successfully!")
