@@ -1,7 +1,7 @@
 import asyncio
 import sys
 from functools import wraps
-from typing import Callable, Optional
+from typing import Callable
 
 import rich_click as click
 
@@ -20,7 +20,12 @@ def require_auth(f: Callable) -> Callable:
 
         # Check if user is logged in
         if not auth_service.is_logged_in():
-            console.print("[red]You are not logged in. Use 'hcli login'.[/red]")
+            if auth_service.has_expired_session():
+                current_source = auth_service.get_current_credentials()
+                email = current_source.email if current_source else "unknown"
+                console.print(f"[red]Your session {email} has expired, use 'hcli login'.[/red]")
+            else:
+                console.print("[red]You are not logged in. Use 'hcli login'.[/red]")
             sys.exit(1)
 
         return f(*args, **kwargs)
@@ -52,7 +57,12 @@ def enforce_login() -> bool:
     auth_service = get_auth_service()
 
     if not auth_service.is_logged_in():
-        console.print("[red]You are not logged in. Use 'hcli login'.[/red]")
+        if auth_service.has_expired_session():
+            current_source = auth_service.get_current_credentials()
+            email = current_source.email if current_source else "unknown"
+            console.print(f"[red]Your session {email} has expired, use 'hcli login'.[/red]")
+        else:
+            console.print("[red]You are not logged in. Use 'hcli login'.[/red]")
         sys.exit(1)
 
     return True
@@ -68,7 +78,7 @@ class BaseCommand(click.RichCommand):
 class AuthCommand(BaseCommand):
     """Command class that requires authentication."""
 
-    def __init__(self, *args, auth_type: Optional[str] = None, **kwargs):
+    def __init__(self, *args, auth_type: str | None = None, **kwargs):
         super().__init__(*args, **kwargs)
         self.auth_type = auth_type
 
@@ -97,7 +107,12 @@ class AuthCommand(BaseCommand):
 
         # Check if user is logged in
         if not auth_service.is_logged_in():
-            console.print("[red]You are not logged in. Use 'hcli login'.[/red]")
+            if auth_service.has_expired_session():
+                current_source = auth_service.get_current_credentials()
+                email = current_source.email if current_source else "unknown"
+                console.print(f"[red]Your session {email} has expired, use 'hcli login'.[/red]")
+            else:
+                console.print("[red]You are not logged in. Use 'hcli login'.[/red]")
             sys.exit(1)
 
         # Validate forced credentials exists
@@ -138,7 +153,7 @@ def base_command(*args, **kwargs):
     return click.command(*args, **kwargs)
 
 
-def auth_command(*args, auth_type: Optional[str] = None, **kwargs):
+def auth_command(*args, auth_type: str | None = None, **kwargs):
     """Decorator for creating an authenticated command."""
     kwargs.setdefault("cls", AuthCommand)
 
