@@ -1,12 +1,13 @@
 """File I/O and system utilities."""
 
 import asyncio
+import asyncio.subprocess
 import os
 import platform
 import shutil
+import sys
 import webbrowser
 from pathlib import Path
-from typing import Optional
 
 from hcli.env import ENV
 
@@ -52,6 +53,16 @@ def dir_exists(path: str) -> bool:
         return False
 
 
+def get_executable_path() -> Path:
+    """Get the path of the current executable (works with PyInstaller)"""
+    if getattr(sys, "frozen", False):
+        # Running as PyInstaller executable
+        return Path(sys.executable)
+    else:
+        # Running as Python script
+        return Path(__file__)
+
+
 def get_binary_name() -> str:
     """Get the binary name for the current platform."""
     if platform.system() == "Windows":
@@ -60,6 +71,30 @@ def get_binary_name() -> str:
         return ENV.HCLI_BINARY_NAME
 
 
+def get_hcli_executable_path() -> str:
+    """Get the path to the hcli executable."""
+    # Check if we're running from a frozen binary
+    if getattr(sys, "frozen", False):
+        return sys.executable
+
+    # Check if hcli is in PATH
+    hcli_path = shutil.which("hcli")
+    if hcli_path:
+        return hcli_path
+
+    # Check if uv is available (development environment)
+    uv_path = shutil.which("uv")
+    if uv_path:
+        return f'"{uv_path}" run hcli'
+
+    # Fallback to python -m hcli
+    python_path = shutil.which("python") or shutil.which("python3")
+    if python_path:
+        return f'"{python_path}" -m hcli'
+
+    raise RuntimeError("Could not find hcli executable")
+
+
 async def remove_dir(path: str) -> bool:
     """Remove a directory and all its contents."""
     try:
@@ -234,7 +269,7 @@ def get_path_separator() -> str:
     return os.sep
 
 
-def get_home_dir() -> Optional[str]:
+def get_home_dir() -> str | None:
     """Get the user's home directory."""
     return str(Path.home()) if Path.home() else None
 
